# PythonPackageVersionsResponseVersions

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**package_name** | **str** | Name of the package. |
**package_version** | **str** | Version of the package. |
**index_url** | **str** | Source index URL of the package. |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
